function [approx_sol,error] = finite_diff_bvp_solver(a,b,n)
%function [approx_sol, err] = finite_diff_bvp_solver(a,b,n)
%solves a two point boundary value problem with rhs
%f defined below on [a,b] with n subintervals
%P.C MA 428

%set up function
r = @(x) exp(x);
f = @(x) -2+(pi^2 + exp(x)).*sin(pi*x) + exp(x).*x.^2;

%set up boundary conditions
alpha = 0.0;
beta = 1.0;

%set up the grid
h=(b-a)/n;
x=[h:h:(n-1)*h]';

%assemble the matrix A (store as sparse)
A = sparse(diag(2 + h^2*r(x),0) + diag(-ones(n-2,1),1) + diag(-ones(n-2,1),-1));
A = (1/h^2)*A;

%assemble right-hand side vector
b= f(x);
%add boundary conditions
b(1) = b(1) + alpha/h^2;
b(n-1) = b(n-1) + beta/h^2;

%compute approximate solution
approx_sol = A\b;

%compute error
true_solution = x.^2 + sin(pi*x);
error = max(abs(true_solution - approx_sol));

%plot approx solution and true solution

end
